@@ -377,12 +377,12 @@ void rfc822db_template_dump(const void *node, const VISIT which, const int depth
         break;
     case postorder: 
     case leaf:
-        p = template_lget((struct template *) t, NULL, "tag");
+        p = template_lget(t, NULL, "tag");
         INFO(INFO_VERBOSE, "dumping template %s", p);
 
         for (field = template_fields_list; *field != NULL; field++)
         {
-            p = template_lget((struct template *) t, NULL, *field);
+            p = template_lget(t, NULL, *field);
             if (p != NULL)
             {
                 if (strcmp(*field, "tag") == 0)
@@ -393,13 +393,13 @@ void rfc822db_template_dump(const void *node, const VISIT which, const int depth
             }
         }
     
-        lang = template_next_lang((struct template *) t, NULL);
+        lang = template_next_lang(t, NULL);
         while (lang) 
         {
             for (field = template_fields_list; *field != NULL; field++)
             {
-                p = template_lget((struct template *) t, lang, *field);
-                if (p != NULL && p != template_lget((struct template *) t, NULL, *field))
+                p = template_lget(t, lang, *field);
+                if (p != NULL && p != template_lget(t, NULL, *field))
                 {
                     if (strcmp(lang, "C") == 0)
                         fprintf(outf, "%c%s-C: %s\n",
@@ -409,7 +409,7 @@ void rfc822db_template_dump(const void *node, const VISIT which, const int depth
                             toupper((*field)[0]), (*field)+1, lang, escapestr(p));
                 }
             }
-            lang = template_next_lang((struct template *) t, lang);
+            lang = template_next_lang(t, lang);
         }
         fprintf(outf, "\n");
     }
@@ -797,21 +797,6 @@ static int rfc822db_question_set(struct question_db *db, struct question *questi
     return DC_OK;
 }
 
-static int rfc822db_question_disown(struct question_db *db, const char *tag, 
-    const char *owner)
-{
-    struct question *q = rfc822db_question_get(db, tag);
-    /*    fprintf(stderr,"rfc822db_question_disown(db, tag=%s, owner=%s)\n",
-          tag,owner);*/
-    if (q == NULL) 
-        return DC_NOTOK;
-    question_owner_delete(q, owner);
-    rfc822db_question_set(db, q);
-    question_deref(q);
-
-    return DC_OK;
-}
-
 static int rfc822db_question_remove(struct question_db *db, const char *tag)
 {
     struct question_db_cache *dbdata = db->data;
@@ -832,6 +817,24 @@ static int rfc822db_question_remove(struct question_db *db, const char *tag)
     return DC_NOTOK;
 }
 
+static int rfc822db_question_disown(struct question_db *db, const char *tag, 
+    const char *owner)
+{
+    struct question *q = rfc822db_question_get(db, tag);
+    /*    fprintf(stderr,"rfc822db_question_disown(db, tag=%s, owner=%s)\n",
+          tag,owner);*/
+    if (q == NULL) 
+        return DC_NOTOK;
+    question_owner_delete(q, owner);
+    if (q->owners == NULL)
+        rfc822db_question_remove(db, q->tag);
+    else
+        rfc822db_question_set(db, q);
+    question_deref(q);
+
+    return DC_OK;
+}
+
 /* TODO: This is an ugly hack because there's no better way to do this
  * within the constraints of twalk() (since there's no user-data argument).
  * If we ever switch to some other tree API, this should go away
@@ -880,27 +883,27 @@ static struct question *rfc822db_question_iterate(struct question_db *db,
 }
 
 struct template_db_module debconf_template_db_module = {
-    initialize: rfc822db_template_initialize,
-    shutdown: rfc822db_template_shutdown,
-    load: rfc822db_template_load,
-    reload: rfc822db_template_reload,
-    save: rfc822db_template_save,
-    set: rfc822db_template_set,
-    get: rfc822db_template_get,
-    remove: rfc822db_template_remove,
-    iterate: rfc822db_template_iterate,
+    .initialize = rfc822db_template_initialize,
+    .shutdown = rfc822db_template_shutdown,
+    .load = rfc822db_template_load,
+    .reload = rfc822db_template_reload,
+    .save = rfc822db_template_save,
+    .set = rfc822db_template_set,
+    .get = rfc822db_template_get,
+    .remove = rfc822db_template_remove,
+    .iterate = rfc822db_template_iterate,
 };
 
 struct question_db_module debconf_question_db_module = {
-    initialize: rfc822db_question_initialize,
-    shutdown: rfc822db_question_shutdown,
-    load: rfc822db_question_load,
-    save: rfc822db_question_save,
-    set: rfc822db_question_set,
-    get: rfc822db_question_get,
-    disown: rfc822db_question_disown,
-    remove: rfc822db_question_remove,
-    iterate: rfc822db_question_iterate,
+    .initialize = rfc822db_question_initialize,
+    .shutdown = rfc822db_question_shutdown,
+    .load = rfc822db_question_load,
+    .save = rfc822db_question_save,
+    .set = rfc822db_question_set,
+    .get = rfc822db_question_get,
+    .disown = rfc822db_question_disown,
+    .remove = rfc822db_question_remove,
+    .iterate = rfc822db_question_iterate,
 };
 
 void dump_question(struct question *q) {
